import reflex as rx

class IoAccessibilityOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoAccessibilityOutline"


class IoAccessibilitySharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoAccessibilitySharp"


class IoAccessibility(rx.Component):
    library = "react-icons/io5"
    tag = "IoAccessibility"


class IoAddCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoAddCircleOutline"


class IoAddCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoAddCircleSharp"


class IoAddCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoAddCircle"


class IoAddOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoAddOutline"


class IoAddSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoAddSharp"


class IoAdd(rx.Component):
    library = "react-icons/io5"
    tag = "IoAdd"


class IoAirplaneOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoAirplaneOutline"


class IoAirplaneSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoAirplaneSharp"


class IoAirplane(rx.Component):
    library = "react-icons/io5"
    tag = "IoAirplane"


class IoAlarmOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoAlarmOutline"


class IoAlarmSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoAlarmSharp"


class IoAlarm(rx.Component):
    library = "react-icons/io5"
    tag = "IoAlarm"


class IoAlbumsOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoAlbumsOutline"


class IoAlbumsSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoAlbumsSharp"


class IoAlbums(rx.Component):
    library = "react-icons/io5"
    tag = "IoAlbums"


class IoAlertCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoAlertCircleOutline"


class IoAlertCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoAlertCircleSharp"


class IoAlertCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoAlertCircle"


class IoAlertOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoAlertOutline"


class IoAlertSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoAlertSharp"


class IoAlert(rx.Component):
    library = "react-icons/io5"
    tag = "IoAlert"


class IoAmericanFootballOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoAmericanFootballOutline"


class IoAmericanFootballSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoAmericanFootballSharp"


class IoAmericanFootball(rx.Component):
    library = "react-icons/io5"
    tag = "IoAmericanFootball"


class IoAnalyticsOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoAnalyticsOutline"


class IoAnalyticsSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoAnalyticsSharp"


class IoAnalytics(rx.Component):
    library = "react-icons/io5"
    tag = "IoAnalytics"


class IoApertureOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoApertureOutline"


class IoApertureSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoApertureSharp"


class IoAperture(rx.Component):
    library = "react-icons/io5"
    tag = "IoAperture"


class IoAppsOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoAppsOutline"


class IoAppsSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoAppsSharp"


class IoApps(rx.Component):
    library = "react-icons/io5"
    tag = "IoApps"


class IoArchiveOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoArchiveOutline"


class IoArchiveSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoArchiveSharp"


class IoArchive(rx.Component):
    library = "react-icons/io5"
    tag = "IoArchive"


class IoArrowBackCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowBackCircleOutline"


class IoArrowBackCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowBackCircleSharp"


class IoArrowBackCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowBackCircle"


class IoArrowBackOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowBackOutline"


class IoArrowBackSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowBackSharp"


class IoArrowBack(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowBack"


class IoArrowDownCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowDownCircleOutline"


class IoArrowDownCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowDownCircleSharp"


class IoArrowDownCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowDownCircle"


class IoArrowDownOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowDownOutline"


class IoArrowDownSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowDownSharp"


class IoArrowDown(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowDown"


class IoArrowForwardCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowForwardCircleOutline"


class IoArrowForwardCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowForwardCircleSharp"


class IoArrowForwardCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowForwardCircle"


class IoArrowForwardOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowForwardOutline"


class IoArrowForwardSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowForwardSharp"


class IoArrowForward(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowForward"


class IoArrowRedoCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowRedoCircleOutline"


class IoArrowRedoCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowRedoCircleSharp"


class IoArrowRedoCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowRedoCircle"


class IoArrowRedoOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowRedoOutline"


class IoArrowRedoSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowRedoSharp"


class IoArrowRedo(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowRedo"


class IoArrowUndoCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowUndoCircleOutline"


class IoArrowUndoCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowUndoCircleSharp"


class IoArrowUndoCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowUndoCircle"


class IoArrowUndoOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowUndoOutline"


class IoArrowUndoSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowUndoSharp"


class IoArrowUndo(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowUndo"


class IoArrowUpCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowUpCircleOutline"


class IoArrowUpCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowUpCircleSharp"


class IoArrowUpCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowUpCircle"


class IoArrowUpOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowUpOutline"


class IoArrowUpSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowUpSharp"


class IoArrowUp(rx.Component):
    library = "react-icons/io5"
    tag = "IoArrowUp"


class IoAtCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoAtCircleOutline"


class IoAtCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoAtCircleSharp"


class IoAtCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoAtCircle"


class IoAtOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoAtOutline"


class IoAtSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoAtSharp"


class IoAt(rx.Component):
    library = "react-icons/io5"
    tag = "IoAt"


class IoAttachOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoAttachOutline"


class IoAttachSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoAttachSharp"


class IoAttach(rx.Component):
    library = "react-icons/io5"
    tag = "IoAttach"


class IoBackspaceOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBackspaceOutline"


class IoBackspaceSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBackspaceSharp"


class IoBackspace(rx.Component):
    library = "react-icons/io5"
    tag = "IoBackspace"


class IoBagAddOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBagAddOutline"


class IoBagAddSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBagAddSharp"


class IoBagAdd(rx.Component):
    library = "react-icons/io5"
    tag = "IoBagAdd"


class IoBagCheckOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBagCheckOutline"


class IoBagCheckSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBagCheckSharp"


class IoBagCheck(rx.Component):
    library = "react-icons/io5"
    tag = "IoBagCheck"


class IoBagHandleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBagHandleOutline"


class IoBagHandleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBagHandleSharp"


class IoBagHandle(rx.Component):
    library = "react-icons/io5"
    tag = "IoBagHandle"


class IoBagOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBagOutline"


class IoBagRemoveOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBagRemoveOutline"


class IoBagRemoveSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBagRemoveSharp"


class IoBagRemove(rx.Component):
    library = "react-icons/io5"
    tag = "IoBagRemove"


class IoBagSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBagSharp"


class IoBag(rx.Component):
    library = "react-icons/io5"
    tag = "IoBag"


class IoBalloonOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBalloonOutline"


class IoBalloonSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBalloonSharp"


class IoBalloon(rx.Component):
    library = "react-icons/io5"
    tag = "IoBalloon"


class IoBanOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBanOutline"


class IoBanSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBanSharp"


class IoBan(rx.Component):
    library = "react-icons/io5"
    tag = "IoBan"


class IoBandageOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBandageOutline"


class IoBandageSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBandageSharp"


class IoBandage(rx.Component):
    library = "react-icons/io5"
    tag = "IoBandage"


class IoBarChartOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBarChartOutline"


class IoBarChartSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBarChartSharp"


class IoBarChart(rx.Component):
    library = "react-icons/io5"
    tag = "IoBarChart"


class IoBarbellOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBarbellOutline"


class IoBarbellSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBarbellSharp"


class IoBarbell(rx.Component):
    library = "react-icons/io5"
    tag = "IoBarbell"


class IoBarcodeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBarcodeOutline"


class IoBarcodeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBarcodeSharp"


class IoBarcode(rx.Component):
    library = "react-icons/io5"
    tag = "IoBarcode"


class IoBaseballOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBaseballOutline"


class IoBaseballSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBaseballSharp"


class IoBaseball(rx.Component):
    library = "react-icons/io5"
    tag = "IoBaseball"


class IoBasketOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBasketOutline"


class IoBasketSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBasketSharp"


class IoBasket(rx.Component):
    library = "react-icons/io5"
    tag = "IoBasket"


class IoBasketballOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBasketballOutline"


class IoBasketballSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBasketballSharp"


class IoBasketball(rx.Component):
    library = "react-icons/io5"
    tag = "IoBasketball"


class IoBatteryChargingOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBatteryChargingOutline"


class IoBatteryChargingSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBatteryChargingSharp"


class IoBatteryCharging(rx.Component):
    library = "react-icons/io5"
    tag = "IoBatteryCharging"


class IoBatteryDeadOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBatteryDeadOutline"


class IoBatteryDeadSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBatteryDeadSharp"


class IoBatteryDead(rx.Component):
    library = "react-icons/io5"
    tag = "IoBatteryDead"


class IoBatteryFullOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBatteryFullOutline"


class IoBatteryFullSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBatteryFullSharp"


class IoBatteryFull(rx.Component):
    library = "react-icons/io5"
    tag = "IoBatteryFull"


class IoBatteryHalfOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBatteryHalfOutline"


class IoBatteryHalfSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBatteryHalfSharp"


class IoBatteryHalf(rx.Component):
    library = "react-icons/io5"
    tag = "IoBatteryHalf"


class IoBeakerOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBeakerOutline"


class IoBeakerSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBeakerSharp"


class IoBeaker(rx.Component):
    library = "react-icons/io5"
    tag = "IoBeaker"


class IoBedOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBedOutline"


class IoBedSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBedSharp"


class IoBed(rx.Component):
    library = "react-icons/io5"
    tag = "IoBed"


class IoBeerOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBeerOutline"


class IoBeerSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBeerSharp"


class IoBeer(rx.Component):
    library = "react-icons/io5"
    tag = "IoBeer"


class IoBicycleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBicycleOutline"


class IoBicycleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBicycleSharp"


class IoBicycle(rx.Component):
    library = "react-icons/io5"
    tag = "IoBicycle"


class IoBluetoothOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBluetoothOutline"


class IoBluetoothSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBluetoothSharp"


class IoBluetooth(rx.Component):
    library = "react-icons/io5"
    tag = "IoBluetooth"


class IoBoatOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBoatOutline"


class IoBoatSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBoatSharp"


class IoBoat(rx.Component):
    library = "react-icons/io5"
    tag = "IoBoat"


class IoBodyOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBodyOutline"


class IoBodySharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBodySharp"


class IoBody(rx.Component):
    library = "react-icons/io5"
    tag = "IoBody"


class IoBonfireOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBonfireOutline"


class IoBonfireSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBonfireSharp"


class IoBonfire(rx.Component):
    library = "react-icons/io5"
    tag = "IoBonfire"


class IoBookOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBookOutline"


class IoBookSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBookSharp"


class IoBook(rx.Component):
    library = "react-icons/io5"
    tag = "IoBook"


class IoBookmarkOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBookmarkOutline"


class IoBookmarkSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBookmarkSharp"


class IoBookmark(rx.Component):
    library = "react-icons/io5"
    tag = "IoBookmark"


class IoBookmarksOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBookmarksOutline"


class IoBookmarksSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBookmarksSharp"


class IoBookmarks(rx.Component):
    library = "react-icons/io5"
    tag = "IoBookmarks"


class IoBowlingBallOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBowlingBallOutline"


class IoBowlingBallSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBowlingBallSharp"


class IoBowlingBall(rx.Component):
    library = "react-icons/io5"
    tag = "IoBowlingBall"


class IoBriefcaseOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBriefcaseOutline"


class IoBriefcaseSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBriefcaseSharp"


class IoBriefcase(rx.Component):
    library = "react-icons/io5"
    tag = "IoBriefcase"


class IoBrowsersOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBrowsersOutline"


class IoBrowsersSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBrowsersSharp"


class IoBrowsers(rx.Component):
    library = "react-icons/io5"
    tag = "IoBrowsers"


class IoBrushOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBrushOutline"


class IoBrushSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBrushSharp"


class IoBrush(rx.Component):
    library = "react-icons/io5"
    tag = "IoBrush"


class IoBugOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBugOutline"


class IoBugSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBugSharp"


class IoBug(rx.Component):
    library = "react-icons/io5"
    tag = "IoBug"


class IoBuildOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBuildOutline"


class IoBuildSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBuildSharp"


class IoBuild(rx.Component):
    library = "react-icons/io5"
    tag = "IoBuild"


class IoBulbOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBulbOutline"


class IoBulbSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBulbSharp"


class IoBulb(rx.Component):
    library = "react-icons/io5"
    tag = "IoBulb"


class IoBusOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBusOutline"


class IoBusSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBusSharp"


class IoBus(rx.Component):
    library = "react-icons/io5"
    tag = "IoBus"


class IoBusinessOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoBusinessOutline"


class IoBusinessSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoBusinessSharp"


class IoBusiness(rx.Component):
    library = "react-icons/io5"
    tag = "IoBusiness"


class IoCafeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCafeOutline"


class IoCafeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCafeSharp"


class IoCafe(rx.Component):
    library = "react-icons/io5"
    tag = "IoCafe"


class IoCalculatorOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCalculatorOutline"


class IoCalculatorSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCalculatorSharp"


class IoCalculator(rx.Component):
    library = "react-icons/io5"
    tag = "IoCalculator"


class IoCalendarClearOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCalendarClearOutline"


class IoCalendarClearSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCalendarClearSharp"


class IoCalendarClear(rx.Component):
    library = "react-icons/io5"
    tag = "IoCalendarClear"


class IoCalendarNumberOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCalendarNumberOutline"


class IoCalendarNumberSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCalendarNumberSharp"


class IoCalendarNumber(rx.Component):
    library = "react-icons/io5"
    tag = "IoCalendarNumber"


class IoCalendarOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCalendarOutline"


class IoCalendarSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCalendarSharp"


class IoCalendar(rx.Component):
    library = "react-icons/io5"
    tag = "IoCalendar"


class IoCallOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCallOutline"


class IoCallSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCallSharp"


class IoCall(rx.Component):
    library = "react-icons/io5"
    tag = "IoCall"


class IoCameraOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCameraOutline"


class IoCameraReverseOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCameraReverseOutline"


class IoCameraReverseSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCameraReverseSharp"


class IoCameraReverse(rx.Component):
    library = "react-icons/io5"
    tag = "IoCameraReverse"


class IoCameraSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCameraSharp"


class IoCamera(rx.Component):
    library = "react-icons/io5"
    tag = "IoCamera"


class IoCarOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCarOutline"


class IoCarSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCarSharp"


class IoCarSportOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCarSportOutline"


class IoCarSportSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCarSportSharp"


class IoCarSport(rx.Component):
    library = "react-icons/io5"
    tag = "IoCarSport"


class IoCar(rx.Component):
    library = "react-icons/io5"
    tag = "IoCar"


class IoCardOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCardOutline"


class IoCardSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCardSharp"


class IoCard(rx.Component):
    library = "react-icons/io5"
    tag = "IoCard"


class IoCaretBackCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretBackCircleOutline"


class IoCaretBackCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretBackCircleSharp"


class IoCaretBackCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretBackCircle"


class IoCaretBackOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretBackOutline"


class IoCaretBackSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretBackSharp"


class IoCaretBack(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretBack"


class IoCaretDownCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretDownCircleOutline"


class IoCaretDownCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretDownCircleSharp"


class IoCaretDownCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretDownCircle"


class IoCaretDownOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretDownOutline"


class IoCaretDownSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretDownSharp"


class IoCaretDown(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretDown"


class IoCaretForwardCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretForwardCircleOutline"


class IoCaretForwardCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretForwardCircleSharp"


class IoCaretForwardCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretForwardCircle"


class IoCaretForwardOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretForwardOutline"


class IoCaretForwardSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretForwardSharp"


class IoCaretForward(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretForward"


class IoCaretUpCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretUpCircleOutline"


class IoCaretUpCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretUpCircleSharp"


class IoCaretUpCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretUpCircle"


class IoCaretUpOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretUpOutline"


class IoCaretUpSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretUpSharp"


class IoCaretUp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCaretUp"


class IoCartOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCartOutline"


class IoCartSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCartSharp"


class IoCart(rx.Component):
    library = "react-icons/io5"
    tag = "IoCart"


class IoCashOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCashOutline"


class IoCashSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCashSharp"


class IoCash(rx.Component):
    library = "react-icons/io5"
    tag = "IoCash"


class IoCellularOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCellularOutline"


class IoCellularSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCellularSharp"


class IoCellular(rx.Component):
    library = "react-icons/io5"
    tag = "IoCellular"


class IoChatboxEllipsesOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoChatboxEllipsesOutline"


class IoChatboxEllipsesSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoChatboxEllipsesSharp"


class IoChatboxEllipses(rx.Component):
    library = "react-icons/io5"
    tag = "IoChatboxEllipses"


class IoChatboxOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoChatboxOutline"


class IoChatboxSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoChatboxSharp"


class IoChatbox(rx.Component):
    library = "react-icons/io5"
    tag = "IoChatbox"


class IoChatbubbleEllipsesOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoChatbubbleEllipsesOutline"


class IoChatbubbleEllipsesSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoChatbubbleEllipsesSharp"


class IoChatbubbleEllipses(rx.Component):
    library = "react-icons/io5"
    tag = "IoChatbubbleEllipses"


class IoChatbubbleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoChatbubbleOutline"


class IoChatbubbleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoChatbubbleSharp"


class IoChatbubble(rx.Component):
    library = "react-icons/io5"
    tag = "IoChatbubble"


class IoChatbubblesOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoChatbubblesOutline"


class IoChatbubblesSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoChatbubblesSharp"


class IoChatbubbles(rx.Component):
    library = "react-icons/io5"
    tag = "IoChatbubbles"


class IoCheckboxOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCheckboxOutline"


class IoCheckboxSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCheckboxSharp"


class IoCheckbox(rx.Component):
    library = "react-icons/io5"
    tag = "IoCheckbox"


class IoCheckmarkCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCheckmarkCircleOutline"


class IoCheckmarkCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCheckmarkCircleSharp"


class IoCheckmarkCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoCheckmarkCircle"


class IoCheckmarkDoneCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCheckmarkDoneCircleOutline"


class IoCheckmarkDoneCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCheckmarkDoneCircleSharp"


class IoCheckmarkDoneCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoCheckmarkDoneCircle"


class IoCheckmarkDoneOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCheckmarkDoneOutline"


class IoCheckmarkDoneSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCheckmarkDoneSharp"


class IoCheckmarkDone(rx.Component):
    library = "react-icons/io5"
    tag = "IoCheckmarkDone"


class IoCheckmarkOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCheckmarkOutline"


class IoCheckmarkSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCheckmarkSharp"


class IoCheckmark(rx.Component):
    library = "react-icons/io5"
    tag = "IoCheckmark"


class IoChevronBackCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronBackCircleOutline"


class IoChevronBackCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronBackCircleSharp"


class IoChevronBackCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronBackCircle"


class IoChevronBackOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronBackOutline"


class IoChevronBackSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronBackSharp"


class IoChevronBack(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronBack"


class IoChevronDownCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronDownCircleOutline"


class IoChevronDownCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronDownCircleSharp"


class IoChevronDownCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronDownCircle"


class IoChevronDownOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronDownOutline"


class IoChevronDownSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronDownSharp"


class IoChevronDown(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronDown"


class IoChevronForwardCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronForwardCircleOutline"


class IoChevronForwardCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronForwardCircleSharp"


class IoChevronForwardCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronForwardCircle"


class IoChevronForwardOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronForwardOutline"


class IoChevronForwardSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronForwardSharp"


class IoChevronForward(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronForward"


class IoChevronUpCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronUpCircleOutline"


class IoChevronUpCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronUpCircleSharp"


class IoChevronUpCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronUpCircle"


class IoChevronUpOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronUpOutline"


class IoChevronUpSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronUpSharp"


class IoChevronUp(rx.Component):
    library = "react-icons/io5"
    tag = "IoChevronUp"


class IoClipboardOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoClipboardOutline"


class IoClipboardSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoClipboardSharp"


class IoClipboard(rx.Component):
    library = "react-icons/io5"
    tag = "IoClipboard"


class IoCloseCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloseCircleOutline"


class IoCloseCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloseCircleSharp"


class IoCloseCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloseCircle"


class IoCloseOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloseOutline"


class IoCloseSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloseSharp"


class IoClose(rx.Component):
    library = "react-icons/io5"
    tag = "IoClose"


class IoCloudCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudCircleOutline"


class IoCloudCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudCircleSharp"


class IoCloudCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudCircle"


class IoCloudDoneOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudDoneOutline"


class IoCloudDoneSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudDoneSharp"


class IoCloudDone(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudDone"


class IoCloudDownloadOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudDownloadOutline"


class IoCloudDownloadSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudDownloadSharp"


class IoCloudDownload(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudDownload"


class IoCloudOfflineOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudOfflineOutline"


class IoCloudOfflineSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudOfflineSharp"


class IoCloudOffline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudOffline"


class IoCloudOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudOutline"


class IoCloudSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudSharp"


class IoCloudUploadOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudUploadOutline"


class IoCloudUploadSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudUploadSharp"


class IoCloudUpload(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudUpload"


class IoCloud(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloud"


class IoCloudyNightOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudyNightOutline"


class IoCloudyNightSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudyNightSharp"


class IoCloudyNight(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudyNight"


class IoCloudyOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudyOutline"


class IoCloudySharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudySharp"


class IoCloudy(rx.Component):
    library = "react-icons/io5"
    tag = "IoCloudy"


class IoCodeDownloadOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCodeDownloadOutline"


class IoCodeDownloadSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCodeDownloadSharp"


class IoCodeDownload(rx.Component):
    library = "react-icons/io5"
    tag = "IoCodeDownload"


class IoCodeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCodeOutline"


class IoCodeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCodeSharp"


class IoCodeSlashOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCodeSlashOutline"


class IoCodeSlashSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCodeSlashSharp"


class IoCodeSlash(rx.Component):
    library = "react-icons/io5"
    tag = "IoCodeSlash"


class IoCodeWorkingOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCodeWorkingOutline"


class IoCodeWorkingSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCodeWorkingSharp"


class IoCodeWorking(rx.Component):
    library = "react-icons/io5"
    tag = "IoCodeWorking"


class IoCode(rx.Component):
    library = "react-icons/io5"
    tag = "IoCode"


class IoCogOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCogOutline"


class IoCogSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCogSharp"


class IoCog(rx.Component):
    library = "react-icons/io5"
    tag = "IoCog"


class IoColorFillOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoColorFillOutline"


class IoColorFillSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoColorFillSharp"


class IoColorFill(rx.Component):
    library = "react-icons/io5"
    tag = "IoColorFill"


class IoColorFilterOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoColorFilterOutline"


class IoColorFilterSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoColorFilterSharp"


class IoColorFilter(rx.Component):
    library = "react-icons/io5"
    tag = "IoColorFilter"


class IoColorPaletteOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoColorPaletteOutline"


class IoColorPaletteSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoColorPaletteSharp"


class IoColorPalette(rx.Component):
    library = "react-icons/io5"
    tag = "IoColorPalette"


class IoColorWandOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoColorWandOutline"


class IoColorWandSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoColorWandSharp"


class IoColorWand(rx.Component):
    library = "react-icons/io5"
    tag = "IoColorWand"


class IoCompassOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCompassOutline"


class IoCompassSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCompassSharp"


class IoCompass(rx.Component):
    library = "react-icons/io5"
    tag = "IoCompass"


class IoConstructOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoConstructOutline"


class IoConstructSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoConstructSharp"


class IoConstruct(rx.Component):
    library = "react-icons/io5"
    tag = "IoConstruct"


class IoContractOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoContractOutline"


class IoContractSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoContractSharp"


class IoContract(rx.Component):
    library = "react-icons/io5"
    tag = "IoContract"


class IoContrastOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoContrastOutline"


class IoContrastSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoContrastSharp"


class IoContrast(rx.Component):
    library = "react-icons/io5"
    tag = "IoContrast"


class IoCopyOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCopyOutline"


class IoCopySharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCopySharp"


class IoCopy(rx.Component):
    library = "react-icons/io5"
    tag = "IoCopy"


class IoCreateOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCreateOutline"


class IoCreateSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCreateSharp"


class IoCreate(rx.Component):
    library = "react-icons/io5"
    tag = "IoCreate"


class IoCropOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCropOutline"


class IoCropSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCropSharp"


class IoCrop(rx.Component):
    library = "react-icons/io5"
    tag = "IoCrop"


class IoCubeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCubeOutline"


class IoCubeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCubeSharp"


class IoCube(rx.Component):
    library = "react-icons/io5"
    tag = "IoCube"


class IoCutOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoCutOutline"


class IoCutSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoCutSharp"


class IoCut(rx.Component):
    library = "react-icons/io5"
    tag = "IoCut"


class IoDesktopOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoDesktopOutline"


class IoDesktopSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoDesktopSharp"


class IoDesktop(rx.Component):
    library = "react-icons/io5"
    tag = "IoDesktop"


class IoDiamondOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoDiamondOutline"


class IoDiamondSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoDiamondSharp"


class IoDiamond(rx.Component):
    library = "react-icons/io5"
    tag = "IoDiamond"


class IoDiceOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoDiceOutline"


class IoDiceSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoDiceSharp"


class IoDice(rx.Component):
    library = "react-icons/io5"
    tag = "IoDice"


class IoDiscOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoDiscOutline"


class IoDiscSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoDiscSharp"


class IoDisc(rx.Component):
    library = "react-icons/io5"
    tag = "IoDisc"


class IoDocumentAttachOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoDocumentAttachOutline"


class IoDocumentAttachSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoDocumentAttachSharp"


class IoDocumentAttach(rx.Component):
    library = "react-icons/io5"
    tag = "IoDocumentAttach"


class IoDocumentLockOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoDocumentLockOutline"


class IoDocumentLockSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoDocumentLockSharp"


class IoDocumentLock(rx.Component):
    library = "react-icons/io5"
    tag = "IoDocumentLock"


class IoDocumentOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoDocumentOutline"


class IoDocumentSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoDocumentSharp"


class IoDocumentTextOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoDocumentTextOutline"


class IoDocumentTextSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoDocumentTextSharp"


class IoDocumentText(rx.Component):
    library = "react-icons/io5"
    tag = "IoDocumentText"


class IoDocument(rx.Component):
    library = "react-icons/io5"
    tag = "IoDocument"


class IoDocumentsOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoDocumentsOutline"


class IoDocumentsSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoDocumentsSharp"


class IoDocuments(rx.Component):
    library = "react-icons/io5"
    tag = "IoDocuments"


class IoDownloadOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoDownloadOutline"


class IoDownloadSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoDownloadSharp"


class IoDownload(rx.Component):
    library = "react-icons/io5"
    tag = "IoDownload"


class IoDuplicateOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoDuplicateOutline"


class IoDuplicateSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoDuplicateSharp"


class IoDuplicate(rx.Component):
    library = "react-icons/io5"
    tag = "IoDuplicate"


class IoEarOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoEarOutline"


class IoEarSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoEarSharp"


class IoEar(rx.Component):
    library = "react-icons/io5"
    tag = "IoEar"


class IoEarthOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoEarthOutline"


class IoEarthSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoEarthSharp"


class IoEarth(rx.Component):
    library = "react-icons/io5"
    tag = "IoEarth"


class IoEaselOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoEaselOutline"


class IoEaselSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoEaselSharp"


class IoEasel(rx.Component):
    library = "react-icons/io5"
    tag = "IoEasel"


class IoEggOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoEggOutline"


class IoEggSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoEggSharp"


class IoEgg(rx.Component):
    library = "react-icons/io5"
    tag = "IoEgg"


class IoEllipseOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoEllipseOutline"


class IoEllipseSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoEllipseSharp"


class IoEllipse(rx.Component):
    library = "react-icons/io5"
    tag = "IoEllipse"


class IoEllipsisHorizontalCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoEllipsisHorizontalCircleOutline"


class IoEllipsisHorizontalCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoEllipsisHorizontalCircleSharp"


class IoEllipsisHorizontalCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoEllipsisHorizontalCircle"


class IoEllipsisHorizontalOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoEllipsisHorizontalOutline"


class IoEllipsisHorizontalSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoEllipsisHorizontalSharp"


class IoEllipsisHorizontal(rx.Component):
    library = "react-icons/io5"
    tag = "IoEllipsisHorizontal"


class IoEllipsisVerticalCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoEllipsisVerticalCircleOutline"


class IoEllipsisVerticalCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoEllipsisVerticalCircleSharp"


class IoEllipsisVerticalCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoEllipsisVerticalCircle"


class IoEllipsisVerticalOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoEllipsisVerticalOutline"


class IoEllipsisVerticalSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoEllipsisVerticalSharp"


class IoEllipsisVertical(rx.Component):
    library = "react-icons/io5"
    tag = "IoEllipsisVertical"


class IoEnterOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoEnterOutline"


class IoEnterSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoEnterSharp"


class IoEnter(rx.Component):
    library = "react-icons/io5"
    tag = "IoEnter"


class IoExitOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoExitOutline"


class IoExitSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoExitSharp"


class IoExit(rx.Component):
    library = "react-icons/io5"
    tag = "IoExit"


class IoExpandOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoExpandOutline"


class IoExpandSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoExpandSharp"


class IoExpand(rx.Component):
    library = "react-icons/io5"
    tag = "IoExpand"


class IoExtensionPuzzleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoExtensionPuzzleOutline"


class IoExtensionPuzzleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoExtensionPuzzleSharp"


class IoExtensionPuzzle(rx.Component):
    library = "react-icons/io5"
    tag = "IoExtensionPuzzle"


class IoEyeOffOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoEyeOffOutline"


class IoEyeOffSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoEyeOffSharp"


class IoEyeOff(rx.Component):
    library = "react-icons/io5"
    tag = "IoEyeOff"


class IoEyeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoEyeOutline"


class IoEyeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoEyeSharp"


class IoEye(rx.Component):
    library = "react-icons/io5"
    tag = "IoEye"


class IoEyedropOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoEyedropOutline"


class IoEyedropSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoEyedropSharp"


class IoEyedrop(rx.Component):
    library = "react-icons/io5"
    tag = "IoEyedrop"


class IoFastFoodOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFastFoodOutline"


class IoFastFoodSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFastFoodSharp"


class IoFastFood(rx.Component):
    library = "react-icons/io5"
    tag = "IoFastFood"


class IoFemaleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFemaleOutline"


class IoFemaleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFemaleSharp"


class IoFemale(rx.Component):
    library = "react-icons/io5"
    tag = "IoFemale"


class IoFileTrayFullOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFileTrayFullOutline"


class IoFileTrayFullSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFileTrayFullSharp"


class IoFileTrayFull(rx.Component):
    library = "react-icons/io5"
    tag = "IoFileTrayFull"


class IoFileTrayOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFileTrayOutline"


class IoFileTraySharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFileTraySharp"


class IoFileTrayStackedOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFileTrayStackedOutline"


class IoFileTrayStackedSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFileTrayStackedSharp"


class IoFileTrayStacked(rx.Component):
    library = "react-icons/io5"
    tag = "IoFileTrayStacked"


class IoFileTray(rx.Component):
    library = "react-icons/io5"
    tag = "IoFileTray"


class IoFilmOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFilmOutline"


class IoFilmSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFilmSharp"


class IoFilm(rx.Component):
    library = "react-icons/io5"
    tag = "IoFilm"


class IoFilterCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFilterCircleOutline"


class IoFilterCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFilterCircleSharp"


class IoFilterCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoFilterCircle"


class IoFilterOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFilterOutline"


class IoFilterSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFilterSharp"


class IoFilter(rx.Component):
    library = "react-icons/io5"
    tag = "IoFilter"


class IoFingerPrintOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFingerPrintOutline"


class IoFingerPrintSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFingerPrintSharp"


class IoFingerPrint(rx.Component):
    library = "react-icons/io5"
    tag = "IoFingerPrint"


class IoFishOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFishOutline"


class IoFishSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFishSharp"


class IoFish(rx.Component):
    library = "react-icons/io5"
    tag = "IoFish"


class IoFitnessOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFitnessOutline"


class IoFitnessSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFitnessSharp"


class IoFitness(rx.Component):
    library = "react-icons/io5"
    tag = "IoFitness"


class IoFlagOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlagOutline"


class IoFlagSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlagSharp"


class IoFlag(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlag"


class IoFlameOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlameOutline"


class IoFlameSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlameSharp"


class IoFlame(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlame"


class IoFlashOffOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlashOffOutline"


class IoFlashOffSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlashOffSharp"


class IoFlashOff(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlashOff"


class IoFlashOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlashOutline"


class IoFlashSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlashSharp"


class IoFlash(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlash"


class IoFlashlightOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlashlightOutline"


class IoFlashlightSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlashlightSharp"


class IoFlashlight(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlashlight"


class IoFlaskOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlaskOutline"


class IoFlaskSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlaskSharp"


class IoFlask(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlask"


class IoFlowerOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlowerOutline"


class IoFlowerSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlowerSharp"


class IoFlower(rx.Component):
    library = "react-icons/io5"
    tag = "IoFlower"


class IoFolderOpenOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFolderOpenOutline"


class IoFolderOpenSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFolderOpenSharp"


class IoFolderOpen(rx.Component):
    library = "react-icons/io5"
    tag = "IoFolderOpen"


class IoFolderOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFolderOutline"


class IoFolderSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFolderSharp"


class IoFolder(rx.Component):
    library = "react-icons/io5"
    tag = "IoFolder"


class IoFootballOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFootballOutline"


class IoFootballSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFootballSharp"


class IoFootball(rx.Component):
    library = "react-icons/io5"
    tag = "IoFootball"


class IoFootstepsOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFootstepsOutline"


class IoFootstepsSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFootstepsSharp"


class IoFootsteps(rx.Component):
    library = "react-icons/io5"
    tag = "IoFootsteps"


class IoFunnelOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoFunnelOutline"


class IoFunnelSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoFunnelSharp"


class IoFunnel(rx.Component):
    library = "react-icons/io5"
    tag = "IoFunnel"


class IoGameControllerOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoGameControllerOutline"


class IoGameControllerSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoGameControllerSharp"


class IoGameController(rx.Component):
    library = "react-icons/io5"
    tag = "IoGameController"


class IoGiftOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoGiftOutline"


class IoGiftSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoGiftSharp"


class IoGift(rx.Component):
    library = "react-icons/io5"
    tag = "IoGift"


class IoGitBranchOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitBranchOutline"


class IoGitBranchSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitBranchSharp"


class IoGitBranch(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitBranch"


class IoGitCommitOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitCommitOutline"


class IoGitCommitSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitCommitSharp"


class IoGitCommit(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitCommit"


class IoGitCompareOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitCompareOutline"


class IoGitCompareSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitCompareSharp"


class IoGitCompare(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitCompare"


class IoGitMergeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitMergeOutline"


class IoGitMergeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitMergeSharp"


class IoGitMerge(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitMerge"


class IoGitNetworkOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitNetworkOutline"


class IoGitNetworkSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitNetworkSharp"


class IoGitNetwork(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitNetwork"


class IoGitPullRequestOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitPullRequestOutline"


class IoGitPullRequestSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitPullRequestSharp"


class IoGitPullRequest(rx.Component):
    library = "react-icons/io5"
    tag = "IoGitPullRequest"


class IoGlassesOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoGlassesOutline"


class IoGlassesSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoGlassesSharp"


class IoGlasses(rx.Component):
    library = "react-icons/io5"
    tag = "IoGlasses"


class IoGlobeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoGlobeOutline"


class IoGlobeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoGlobeSharp"


class IoGlobe(rx.Component):
    library = "react-icons/io5"
    tag = "IoGlobe"


class IoGolfOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoGolfOutline"


class IoGolfSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoGolfSharp"


class IoGolf(rx.Component):
    library = "react-icons/io5"
    tag = "IoGolf"


class IoGridOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoGridOutline"


class IoGridSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoGridSharp"


class IoGrid(rx.Component):
    library = "react-icons/io5"
    tag = "IoGrid"


class IoHammerOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoHammerOutline"


class IoHammerSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHammerSharp"


class IoHammer(rx.Component):
    library = "react-icons/io5"
    tag = "IoHammer"


class IoHandLeftOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoHandLeftOutline"


class IoHandLeftSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHandLeftSharp"


class IoHandLeft(rx.Component):
    library = "react-icons/io5"
    tag = "IoHandLeft"


class IoHandRightOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoHandRightOutline"


class IoHandRightSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHandRightSharp"


class IoHandRight(rx.Component):
    library = "react-icons/io5"
    tag = "IoHandRight"


class IoHappyOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoHappyOutline"


class IoHappySharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHappySharp"


class IoHappy(rx.Component):
    library = "react-icons/io5"
    tag = "IoHappy"


class IoHardwareChipOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoHardwareChipOutline"


class IoHardwareChipSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHardwareChipSharp"


class IoHardwareChip(rx.Component):
    library = "react-icons/io5"
    tag = "IoHardwareChip"


class IoHeadsetOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeadsetOutline"


class IoHeadsetSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeadsetSharp"


class IoHeadset(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeadset"


class IoHeartCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeartCircleOutline"


class IoHeartCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeartCircleSharp"


class IoHeartCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeartCircle"


class IoHeartDislikeCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeartDislikeCircleOutline"


class IoHeartDislikeCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeartDislikeCircleSharp"


class IoHeartDislikeCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeartDislikeCircle"


class IoHeartDislikeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeartDislikeOutline"


class IoHeartDislikeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeartDislikeSharp"


class IoHeartDislike(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeartDislike"


class IoHeartHalfOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeartHalfOutline"


class IoHeartHalfSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeartHalfSharp"


class IoHeartHalf(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeartHalf"


class IoHeartOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeartOutline"


class IoHeartSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeartSharp"


class IoHeart(rx.Component):
    library = "react-icons/io5"
    tag = "IoHeart"


class IoHelpBuoyOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoHelpBuoyOutline"


class IoHelpBuoySharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHelpBuoySharp"


class IoHelpBuoy(rx.Component):
    library = "react-icons/io5"
    tag = "IoHelpBuoy"


class IoHelpCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoHelpCircleOutline"


class IoHelpCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHelpCircleSharp"


class IoHelpCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoHelpCircle"


class IoHelpOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoHelpOutline"


class IoHelpSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHelpSharp"


class IoHelp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHelp"


class IoHomeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoHomeOutline"


class IoHomeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHomeSharp"


class IoHome(rx.Component):
    library = "react-icons/io5"
    tag = "IoHome"


class IoHourglassOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoHourglassOutline"


class IoHourglassSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoHourglassSharp"


class IoHourglass(rx.Component):
    library = "react-icons/io5"
    tag = "IoHourglass"


class IoIceCreamOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoIceCreamOutline"


class IoIceCreamSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoIceCreamSharp"


class IoIceCream(rx.Component):
    library = "react-icons/io5"
    tag = "IoIceCream"


class IoIdCardOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoIdCardOutline"


class IoIdCardSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoIdCardSharp"


class IoIdCard(rx.Component):
    library = "react-icons/io5"
    tag = "IoIdCard"


class IoImageOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoImageOutline"


class IoImageSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoImageSharp"


class IoImage(rx.Component):
    library = "react-icons/io5"
    tag = "IoImage"


class IoImagesOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoImagesOutline"


class IoImagesSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoImagesSharp"


class IoImages(rx.Component):
    library = "react-icons/io5"
    tag = "IoImages"


class IoInfiniteOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoInfiniteOutline"


class IoInfiniteSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoInfiniteSharp"


class IoInfinite(rx.Component):
    library = "react-icons/io5"
    tag = "IoInfinite"


class IoInformationCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoInformationCircleOutline"


class IoInformationCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoInformationCircleSharp"


class IoInformationCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoInformationCircle"


class IoInformationOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoInformationOutline"


class IoInformationSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoInformationSharp"


class IoInformation(rx.Component):
    library = "react-icons/io5"
    tag = "IoInformation"


class IoInvertModeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoInvertModeOutline"


class IoInvertModeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoInvertModeSharp"


class IoInvertMode(rx.Component):
    library = "react-icons/io5"
    tag = "IoInvertMode"


class IoJournalOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoJournalOutline"


class IoJournalSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoJournalSharp"


class IoJournal(rx.Component):
    library = "react-icons/io5"
    tag = "IoJournal"


class IoKeyOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoKeyOutline"


class IoKeySharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoKeySharp"


class IoKey(rx.Component):
    library = "react-icons/io5"
    tag = "IoKey"


class IoKeypadOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoKeypadOutline"


class IoKeypadSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoKeypadSharp"


class IoKeypad(rx.Component):
    library = "react-icons/io5"
    tag = "IoKeypad"


class IoLanguageOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoLanguageOutline"


class IoLanguageSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoLanguageSharp"


class IoLanguage(rx.Component):
    library = "react-icons/io5"
    tag = "IoLanguage"


class IoLaptopOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoLaptopOutline"


class IoLaptopSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoLaptopSharp"


class IoLaptop(rx.Component):
    library = "react-icons/io5"
    tag = "IoLaptop"


class IoLayersOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoLayersOutline"


class IoLayersSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoLayersSharp"


class IoLayers(rx.Component):
    library = "react-icons/io5"
    tag = "IoLayers"


class IoLeafOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoLeafOutline"


class IoLeafSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoLeafSharp"


class IoLeaf(rx.Component):
    library = "react-icons/io5"
    tag = "IoLeaf"


class IoLibraryOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoLibraryOutline"


class IoLibrarySharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoLibrarySharp"


class IoLibrary(rx.Component):
    library = "react-icons/io5"
    tag = "IoLibrary"


class IoLinkOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoLinkOutline"


class IoLinkSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoLinkSharp"


class IoLink(rx.Component):
    library = "react-icons/io5"
    tag = "IoLink"


class IoListCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoListCircleOutline"


class IoListCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoListCircleSharp"


class IoListCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoListCircle"


class IoListOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoListOutline"


class IoListSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoListSharp"


class IoList(rx.Component):
    library = "react-icons/io5"
    tag = "IoList"


class IoLocateOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoLocateOutline"


class IoLocateSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoLocateSharp"


class IoLocate(rx.Component):
    library = "react-icons/io5"
    tag = "IoLocate"


class IoLocationOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoLocationOutline"


class IoLocationSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoLocationSharp"


class IoLocation(rx.Component):
    library = "react-icons/io5"
    tag = "IoLocation"


class IoLockClosedOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoLockClosedOutline"


class IoLockClosedSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoLockClosedSharp"


class IoLockClosed(rx.Component):
    library = "react-icons/io5"
    tag = "IoLockClosed"


class IoLockOpenOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoLockOpenOutline"


class IoLockOpenSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoLockOpenSharp"


class IoLockOpen(rx.Component):
    library = "react-icons/io5"
    tag = "IoLockOpen"


class IoLogInOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogInOutline"


class IoLogInSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogInSharp"


class IoLogIn(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogIn"


class IoLogOutOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogOutOutline"


class IoLogOutSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogOutSharp"


class IoLogOut(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogOut"


class IoLogoAlipay(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoAlipay"


class IoLogoAmazon(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoAmazon"


class IoLogoAmplify(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoAmplify"


class IoLogoAndroid(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoAndroid"


class IoLogoAngular(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoAngular"


class IoLogoAppleAppstore(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoAppleAppstore"


class IoLogoAppleAr(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoAppleAr"


class IoLogoApple(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoApple"


class IoLogoBehance(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoBehance"


class IoLogoBitbucket(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoBitbucket"


class IoLogoBitcoin(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoBitcoin"


class IoLogoBuffer(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoBuffer"


class IoLogoCapacitor(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoCapacitor"


class IoLogoChrome(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoChrome"


class IoLogoClosedCaptioning(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoClosedCaptioning"


class IoLogoCodepen(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoCodepen"


class IoLogoCss3(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoCss3"


class IoLogoDesignernews(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoDesignernews"


class IoLogoDeviantart(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoDeviantart"


class IoLogoDiscord(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoDiscord"


class IoLogoDocker(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoDocker"


class IoLogoDribbble(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoDribbble"


class IoLogoDropbox(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoDropbox"


class IoLogoEdge(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoEdge"


class IoLogoElectron(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoElectron"


class IoLogoEuro(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoEuro"


class IoLogoFacebook(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoFacebook"


class IoLogoFigma(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoFigma"


class IoLogoFirebase(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoFirebase"


class IoLogoFirefox(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoFirefox"


class IoLogoFlickr(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoFlickr"


class IoLogoFoursquare(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoFoursquare"


class IoLogoGithub(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoGithub"


class IoLogoGitlab(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoGitlab"


class IoLogoGooglePlaystore(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoGooglePlaystore"


class IoLogoGoogle(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoGoogle"


class IoLogoHackernews(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoHackernews"


class IoLogoHtml5(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoHtml5"


class IoLogoInstagram(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoInstagram"


class IoLogoIonic(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoIonic"


class IoLogoIonitron(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoIonitron"


class IoLogoJavascript(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoJavascript"


class IoLogoLaravel(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoLaravel"


class IoLogoLinkedin(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoLinkedin"


class IoLogoMarkdown(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoMarkdown"


class IoLogoMastodon(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoMastodon"


class IoLogoMedium(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoMedium"


class IoLogoMicrosoft(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoMicrosoft"


class IoLogoNoSmoking(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoNoSmoking"


class IoLogoNodejs(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoNodejs"


class IoLogoNpm(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoNpm"


class IoLogoOctocat(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoOctocat"


class IoLogoPaypal(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoPaypal"


class IoLogoPinterest(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoPinterest"


class IoLogoPlaystation(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoPlaystation"


class IoLogoPwa(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoPwa"


class IoLogoPython(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoPython"


class IoLogoReact(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoReact"


class IoLogoReddit(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoReddit"


class IoLogoRss(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoRss"


class IoLogoSass(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoSass"


class IoLogoSkype(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoSkype"


class IoLogoSlack(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoSlack"


class IoLogoSnapchat(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoSnapchat"


class IoLogoSoundcloud(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoSoundcloud"


class IoLogoStackoverflow(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoStackoverflow"


class IoLogoSteam(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoSteam"


class IoLogoStencil(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoStencil"


class IoLogoTableau(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoTableau"


class IoLogoTiktok(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoTiktok"


class IoLogoTumblr(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoTumblr"


class IoLogoTux(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoTux"


class IoLogoTwitch(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoTwitch"


class IoLogoTwitter(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoTwitter"


class IoLogoUsd(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoUsd"


class IoLogoVenmo(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoVenmo"


class IoLogoVercel(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoVercel"


class IoLogoVimeo(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoVimeo"


class IoLogoVk(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoVk"


class IoLogoVue(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoVue"


class IoLogoWebComponent(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoWebComponent"


class IoLogoWechat(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoWechat"


class IoLogoWhatsapp(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoWhatsapp"


class IoLogoWindows(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoWindows"


class IoLogoWordpress(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoWordpress"


class IoLogoXbox(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoXbox"


class IoLogoXing(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoXing"


class IoLogoYahoo(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoYahoo"


class IoLogoYen(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoYen"


class IoLogoYoutube(rx.Component):
    library = "react-icons/io5"
    tag = "IoLogoYoutube"


class IoMagnetOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMagnetOutline"


class IoMagnetSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMagnetSharp"


class IoMagnet(rx.Component):
    library = "react-icons/io5"
    tag = "IoMagnet"


class IoMailOpenOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMailOpenOutline"


class IoMailOpenSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMailOpenSharp"


class IoMailOpen(rx.Component):
    library = "react-icons/io5"
    tag = "IoMailOpen"


class IoMailOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMailOutline"


class IoMailSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMailSharp"


class IoMailUnreadOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMailUnreadOutline"


class IoMailUnreadSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMailUnreadSharp"


class IoMailUnread(rx.Component):
    library = "react-icons/io5"
    tag = "IoMailUnread"


class IoMail(rx.Component):
    library = "react-icons/io5"
    tag = "IoMail"


class IoMaleFemaleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMaleFemaleOutline"


class IoMaleFemaleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMaleFemaleSharp"


class IoMaleFemale(rx.Component):
    library = "react-icons/io5"
    tag = "IoMaleFemale"


class IoMaleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMaleOutline"


class IoMaleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMaleSharp"


class IoMale(rx.Component):
    library = "react-icons/io5"
    tag = "IoMale"


class IoManOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoManOutline"


class IoManSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoManSharp"


class IoMan(rx.Component):
    library = "react-icons/io5"
    tag = "IoMan"


class IoMapOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMapOutline"


class IoMapSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMapSharp"


class IoMap(rx.Component):
    library = "react-icons/io5"
    tag = "IoMap"


class IoMedalOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMedalOutline"


class IoMedalSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMedalSharp"


class IoMedal(rx.Component):
    library = "react-icons/io5"
    tag = "IoMedal"


class IoMedicalOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMedicalOutline"


class IoMedicalSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMedicalSharp"


class IoMedical(rx.Component):
    library = "react-icons/io5"
    tag = "IoMedical"


class IoMedkitOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMedkitOutline"


class IoMedkitSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMedkitSharp"


class IoMedkit(rx.Component):
    library = "react-icons/io5"
    tag = "IoMedkit"


class IoMegaphoneOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMegaphoneOutline"


class IoMegaphoneSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMegaphoneSharp"


class IoMegaphone(rx.Component):
    library = "react-icons/io5"
    tag = "IoMegaphone"


class IoMenuOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMenuOutline"


class IoMenuSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMenuSharp"


class IoMenu(rx.Component):
    library = "react-icons/io5"
    tag = "IoMenu"


class IoMicCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMicCircleOutline"


class IoMicCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMicCircleSharp"


class IoMicCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoMicCircle"


class IoMicOffCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMicOffCircleOutline"


class IoMicOffCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMicOffCircleSharp"


class IoMicOffCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoMicOffCircle"


class IoMicOffOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMicOffOutline"


class IoMicOffSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMicOffSharp"


class IoMicOff(rx.Component):
    library = "react-icons/io5"
    tag = "IoMicOff"


class IoMicOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMicOutline"


class IoMicSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMicSharp"


class IoMic(rx.Component):
    library = "react-icons/io5"
    tag = "IoMic"


class IoMoonOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMoonOutline"


class IoMoonSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMoonSharp"


class IoMoon(rx.Component):
    library = "react-icons/io5"
    tag = "IoMoon"


class IoMoveOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMoveOutline"


class IoMoveSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMoveSharp"


class IoMove(rx.Component):
    library = "react-icons/io5"
    tag = "IoMove"


class IoMusicalNoteOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMusicalNoteOutline"


class IoMusicalNoteSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMusicalNoteSharp"


class IoMusicalNote(rx.Component):
    library = "react-icons/io5"
    tag = "IoMusicalNote"


class IoMusicalNotesOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoMusicalNotesOutline"


class IoMusicalNotesSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoMusicalNotesSharp"


class IoMusicalNotes(rx.Component):
    library = "react-icons/io5"
    tag = "IoMusicalNotes"


class IoNavigateCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoNavigateCircleOutline"


class IoNavigateCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoNavigateCircleSharp"


class IoNavigateCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoNavigateCircle"


class IoNavigateOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoNavigateOutline"


class IoNavigateSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoNavigateSharp"


class IoNavigate(rx.Component):
    library = "react-icons/io5"
    tag = "IoNavigate"


class IoNewspaperOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoNewspaperOutline"


class IoNewspaperSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoNewspaperSharp"


class IoNewspaper(rx.Component):
    library = "react-icons/io5"
    tag = "IoNewspaper"


class IoNotificationsCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoNotificationsCircleOutline"


class IoNotificationsCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoNotificationsCircleSharp"


class IoNotificationsCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoNotificationsCircle"


class IoNotificationsOffCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoNotificationsOffCircleOutline"


class IoNotificationsOffCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoNotificationsOffCircleSharp"


class IoNotificationsOffCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoNotificationsOffCircle"


class IoNotificationsOffOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoNotificationsOffOutline"


class IoNotificationsOffSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoNotificationsOffSharp"


class IoNotificationsOff(rx.Component):
    library = "react-icons/io5"
    tag = "IoNotificationsOff"


class IoNotificationsOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoNotificationsOutline"


class IoNotificationsSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoNotificationsSharp"


class IoNotifications(rx.Component):
    library = "react-icons/io5"
    tag = "IoNotifications"


class IoNuclearOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoNuclearOutline"


class IoNuclearSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoNuclearSharp"


class IoNuclear(rx.Component):
    library = "react-icons/io5"
    tag = "IoNuclear"


class IoNutritionOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoNutritionOutline"


class IoNutritionSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoNutritionSharp"


class IoNutrition(rx.Component):
    library = "react-icons/io5"
    tag = "IoNutrition"


class IoOpenOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoOpenOutline"


class IoOpenSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoOpenSharp"


class IoOpen(rx.Component):
    library = "react-icons/io5"
    tag = "IoOpen"


class IoOptionsOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoOptionsOutline"


class IoOptionsSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoOptionsSharp"


class IoOptions(rx.Component):
    library = "react-icons/io5"
    tag = "IoOptions"


class IoPaperPlaneOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPaperPlaneOutline"


class IoPaperPlaneSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPaperPlaneSharp"


class IoPaperPlane(rx.Component):
    library = "react-icons/io5"
    tag = "IoPaperPlane"


class IoPartlySunnyOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPartlySunnyOutline"


class IoPartlySunnySharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPartlySunnySharp"


class IoPartlySunny(rx.Component):
    library = "react-icons/io5"
    tag = "IoPartlySunny"


class IoPauseCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPauseCircleOutline"


class IoPauseCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPauseCircleSharp"


class IoPauseCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoPauseCircle"


class IoPauseOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPauseOutline"


class IoPauseSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPauseSharp"


class IoPause(rx.Component):
    library = "react-icons/io5"
    tag = "IoPause"


class IoPawOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPawOutline"


class IoPawSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPawSharp"


class IoPaw(rx.Component):
    library = "react-icons/io5"
    tag = "IoPaw"


class IoPencilOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPencilOutline"


class IoPencilSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPencilSharp"


class IoPencil(rx.Component):
    library = "react-icons/io5"
    tag = "IoPencil"


class IoPeopleCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPeopleCircleOutline"


class IoPeopleCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPeopleCircleSharp"


class IoPeopleCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoPeopleCircle"


class IoPeopleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPeopleOutline"


class IoPeopleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPeopleSharp"


class IoPeople(rx.Component):
    library = "react-icons/io5"
    tag = "IoPeople"


class IoPersonAddOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPersonAddOutline"


class IoPersonAddSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPersonAddSharp"


class IoPersonAdd(rx.Component):
    library = "react-icons/io5"
    tag = "IoPersonAdd"


class IoPersonCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPersonCircleOutline"


class IoPersonCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPersonCircleSharp"


class IoPersonCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoPersonCircle"


class IoPersonOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPersonOutline"


class IoPersonRemoveOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPersonRemoveOutline"


class IoPersonRemoveSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPersonRemoveSharp"


class IoPersonRemove(rx.Component):
    library = "react-icons/io5"
    tag = "IoPersonRemove"


class IoPersonSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPersonSharp"


class IoPerson(rx.Component):
    library = "react-icons/io5"
    tag = "IoPerson"


class IoPhoneLandscapeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPhoneLandscapeOutline"


class IoPhoneLandscapeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPhoneLandscapeSharp"


class IoPhoneLandscape(rx.Component):
    library = "react-icons/io5"
    tag = "IoPhoneLandscape"


class IoPhonePortraitOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPhonePortraitOutline"


class IoPhonePortraitSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPhonePortraitSharp"


class IoPhonePortrait(rx.Component):
    library = "react-icons/io5"
    tag = "IoPhonePortrait"


class IoPieChartOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPieChartOutline"


class IoPieChartSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPieChartSharp"


class IoPieChart(rx.Component):
    library = "react-icons/io5"
    tag = "IoPieChart"


class IoPinOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPinOutline"


class IoPinSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPinSharp"


class IoPin(rx.Component):
    library = "react-icons/io5"
    tag = "IoPin"


class IoPintOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPintOutline"


class IoPintSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPintSharp"


class IoPint(rx.Component):
    library = "react-icons/io5"
    tag = "IoPint"


class IoPizzaOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPizzaOutline"


class IoPizzaSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPizzaSharp"


class IoPizza(rx.Component):
    library = "react-icons/io5"
    tag = "IoPizza"


class IoPlanetOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlanetOutline"


class IoPlanetSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlanetSharp"


class IoPlanet(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlanet"


class IoPlayBackCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlayBackCircleOutline"


class IoPlayBackCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlayBackCircleSharp"


class IoPlayBackCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlayBackCircle"


class IoPlayBackOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlayBackOutline"


class IoPlayBackSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlayBackSharp"


class IoPlayBack(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlayBack"


class IoPlayCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlayCircleOutline"


class IoPlayCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlayCircleSharp"


class IoPlayCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlayCircle"


class IoPlayForwardCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlayForwardCircleOutline"


class IoPlayForwardCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlayForwardCircleSharp"


class IoPlayForwardCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlayForwardCircle"


class IoPlayForwardOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlayForwardOutline"


class IoPlayForwardSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlayForwardSharp"


class IoPlayForward(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlayForward"


class IoPlayOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlayOutline"


class IoPlaySharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlaySharp"


class IoPlaySkipBackCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlaySkipBackCircleOutline"


class IoPlaySkipBackCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlaySkipBackCircleSharp"


class IoPlaySkipBackCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlaySkipBackCircle"


class IoPlaySkipBackOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlaySkipBackOutline"


class IoPlaySkipBackSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlaySkipBackSharp"


class IoPlaySkipBack(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlaySkipBack"


class IoPlaySkipForwardCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlaySkipForwardCircleOutline"


class IoPlaySkipForwardCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlaySkipForwardCircleSharp"


class IoPlaySkipForwardCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlaySkipForwardCircle"


class IoPlaySkipForwardOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlaySkipForwardOutline"


class IoPlaySkipForwardSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlaySkipForwardSharp"


class IoPlaySkipForward(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlaySkipForward"


class IoPlay(rx.Component):
    library = "react-icons/io5"
    tag = "IoPlay"


class IoPodiumOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPodiumOutline"


class IoPodiumSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPodiumSharp"


class IoPodium(rx.Component):
    library = "react-icons/io5"
    tag = "IoPodium"


class IoPowerOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPowerOutline"


class IoPowerSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPowerSharp"


class IoPower(rx.Component):
    library = "react-icons/io5"
    tag = "IoPower"


class IoPricetagOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPricetagOutline"


class IoPricetagSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPricetagSharp"


class IoPricetag(rx.Component):
    library = "react-icons/io5"
    tag = "IoPricetag"


class IoPricetagsOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPricetagsOutline"


class IoPricetagsSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPricetagsSharp"


class IoPricetags(rx.Component):
    library = "react-icons/io5"
    tag = "IoPricetags"


class IoPrintOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPrintOutline"


class IoPrintSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPrintSharp"


class IoPrint(rx.Component):
    library = "react-icons/io5"
    tag = "IoPrint"


class IoPrismOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPrismOutline"


class IoPrismSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPrismSharp"


class IoPrism(rx.Component):
    library = "react-icons/io5"
    tag = "IoPrism"


class IoPulseOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPulseOutline"


class IoPulseSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPulseSharp"


class IoPulse(rx.Component):
    library = "react-icons/io5"
    tag = "IoPulse"


class IoPushOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoPushOutline"


class IoPushSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoPushSharp"


class IoPush(rx.Component):
    library = "react-icons/io5"
    tag = "IoPush"


class IoQrCodeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoQrCodeOutline"


class IoQrCodeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoQrCodeSharp"


class IoQrCode(rx.Component):
    library = "react-icons/io5"
    tag = "IoQrCode"


class IoRadioButtonOffOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoRadioButtonOffOutline"


class IoRadioButtonOffSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoRadioButtonOffSharp"


class IoRadioButtonOff(rx.Component):
    library = "react-icons/io5"
    tag = "IoRadioButtonOff"


class IoRadioButtonOnOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoRadioButtonOnOutline"


class IoRadioButtonOnSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoRadioButtonOnSharp"


class IoRadioButtonOn(rx.Component):
    library = "react-icons/io5"
    tag = "IoRadioButtonOn"


class IoRadioOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoRadioOutline"


class IoRadioSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoRadioSharp"


class IoRadio(rx.Component):
    library = "react-icons/io5"
    tag = "IoRadio"


class IoRainyOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoRainyOutline"


class IoRainySharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoRainySharp"


class IoRainy(rx.Component):
    library = "react-icons/io5"
    tag = "IoRainy"


class IoReaderOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoReaderOutline"


class IoReaderSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoReaderSharp"


class IoReader(rx.Component):
    library = "react-icons/io5"
    tag = "IoReader"


class IoReceiptOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoReceiptOutline"


class IoReceiptSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoReceiptSharp"


class IoReceipt(rx.Component):
    library = "react-icons/io5"
    tag = "IoReceipt"


class IoRecordingOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoRecordingOutline"


class IoRecordingSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoRecordingSharp"


class IoRecording(rx.Component):
    library = "react-icons/io5"
    tag = "IoRecording"


class IoRefreshCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoRefreshCircleOutline"


class IoRefreshCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoRefreshCircleSharp"


class IoRefreshCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoRefreshCircle"


class IoRefreshOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoRefreshOutline"


class IoRefreshSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoRefreshSharp"


class IoRefresh(rx.Component):
    library = "react-icons/io5"
    tag = "IoRefresh"


class IoReloadCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoReloadCircleOutline"


class IoReloadCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoReloadCircleSharp"


class IoReloadCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoReloadCircle"


class IoReloadOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoReloadOutline"


class IoReloadSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoReloadSharp"


class IoReload(rx.Component):
    library = "react-icons/io5"
    tag = "IoReload"


class IoRemoveCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoRemoveCircleOutline"


class IoRemoveCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoRemoveCircleSharp"


class IoRemoveCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoRemoveCircle"


class IoRemoveOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoRemoveOutline"


class IoRemoveSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoRemoveSharp"


class IoRemove(rx.Component):
    library = "react-icons/io5"
    tag = "IoRemove"


class IoReorderFourOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoReorderFourOutline"


class IoReorderFourSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoReorderFourSharp"


class IoReorderFour(rx.Component):
    library = "react-icons/io5"
    tag = "IoReorderFour"


class IoReorderThreeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoReorderThreeOutline"


class IoReorderThreeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoReorderThreeSharp"


class IoReorderThree(rx.Component):
    library = "react-icons/io5"
    tag = "IoReorderThree"


class IoReorderTwoOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoReorderTwoOutline"


class IoReorderTwoSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoReorderTwoSharp"


class IoReorderTwo(rx.Component):
    library = "react-icons/io5"
    tag = "IoReorderTwo"


class IoRepeatOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoRepeatOutline"


class IoRepeatSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoRepeatSharp"


class IoRepeat(rx.Component):
    library = "react-icons/io5"
    tag = "IoRepeat"


class IoResizeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoResizeOutline"


class IoResizeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoResizeSharp"


class IoResize(rx.Component):
    library = "react-icons/io5"
    tag = "IoResize"


class IoRestaurantOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoRestaurantOutline"


class IoRestaurantSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoRestaurantSharp"


class IoRestaurant(rx.Component):
    library = "react-icons/io5"
    tag = "IoRestaurant"


class IoReturnDownBackOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoReturnDownBackOutline"


class IoReturnDownBackSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoReturnDownBackSharp"


class IoReturnDownBack(rx.Component):
    library = "react-icons/io5"
    tag = "IoReturnDownBack"


class IoReturnDownForwardOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoReturnDownForwardOutline"


class IoReturnDownForwardSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoReturnDownForwardSharp"


class IoReturnDownForward(rx.Component):
    library = "react-icons/io5"
    tag = "IoReturnDownForward"


class IoReturnUpBackOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoReturnUpBackOutline"


class IoReturnUpBackSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoReturnUpBackSharp"


class IoReturnUpBack(rx.Component):
    library = "react-icons/io5"
    tag = "IoReturnUpBack"


class IoReturnUpForwardOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoReturnUpForwardOutline"


class IoReturnUpForwardSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoReturnUpForwardSharp"


class IoReturnUpForward(rx.Component):
    library = "react-icons/io5"
    tag = "IoReturnUpForward"


class IoRibbonOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoRibbonOutline"


class IoRibbonSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoRibbonSharp"


class IoRibbon(rx.Component):
    library = "react-icons/io5"
    tag = "IoRibbon"


class IoRocketOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoRocketOutline"


class IoRocketSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoRocketSharp"


class IoRocket(rx.Component):
    library = "react-icons/io5"
    tag = "IoRocket"


class IoRoseOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoRoseOutline"


class IoRoseSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoRoseSharp"


class IoRose(rx.Component):
    library = "react-icons/io5"
    tag = "IoRose"


class IoSadOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSadOutline"


class IoSadSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSadSharp"


class IoSad(rx.Component):
    library = "react-icons/io5"
    tag = "IoSad"


class IoSaveOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSaveOutline"


class IoSaveSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSaveSharp"


class IoSave(rx.Component):
    library = "react-icons/io5"
    tag = "IoSave"


class IoScaleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoScaleOutline"


class IoScaleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoScaleSharp"


class IoScale(rx.Component):
    library = "react-icons/io5"
    tag = "IoScale"


class IoScanCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoScanCircleOutline"


class IoScanCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoScanCircleSharp"


class IoScanCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoScanCircle"


class IoScanOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoScanOutline"


class IoScanSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoScanSharp"


class IoScan(rx.Component):
    library = "react-icons/io5"
    tag = "IoScan"


class IoSchoolOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSchoolOutline"


class IoSchoolSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSchoolSharp"


class IoSchool(rx.Component):
    library = "react-icons/io5"
    tag = "IoSchool"


class IoSearchCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSearchCircleOutline"


class IoSearchCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSearchCircleSharp"


class IoSearchCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoSearchCircle"


class IoSearchOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSearchOutline"


class IoSearchSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSearchSharp"


class IoSearch(rx.Component):
    library = "react-icons/io5"
    tag = "IoSearch"


class IoSendOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSendOutline"


class IoSendSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSendSharp"


class IoSend(rx.Component):
    library = "react-icons/io5"
    tag = "IoSend"


class IoServerOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoServerOutline"


class IoServerSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoServerSharp"


class IoServer(rx.Component):
    library = "react-icons/io5"
    tag = "IoServer"


class IoSettingsOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSettingsOutline"


class IoSettingsSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSettingsSharp"


class IoSettings(rx.Component):
    library = "react-icons/io5"
    tag = "IoSettings"


class IoShapesOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoShapesOutline"


class IoShapesSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoShapesSharp"


class IoShapes(rx.Component):
    library = "react-icons/io5"
    tag = "IoShapes"


class IoShareOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoShareOutline"


class IoShareSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoShareSharp"


class IoShareSocialOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoShareSocialOutline"


class IoShareSocialSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoShareSocialSharp"


class IoShareSocial(rx.Component):
    library = "react-icons/io5"
    tag = "IoShareSocial"


class IoShare(rx.Component):
    library = "react-icons/io5"
    tag = "IoShare"


class IoShieldCheckmarkOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoShieldCheckmarkOutline"


class IoShieldCheckmarkSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoShieldCheckmarkSharp"


class IoShieldCheckmark(rx.Component):
    library = "react-icons/io5"
    tag = "IoShieldCheckmark"


class IoShieldHalfOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoShieldHalfOutline"


class IoShieldHalfSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoShieldHalfSharp"


class IoShieldHalf(rx.Component):
    library = "react-icons/io5"
    tag = "IoShieldHalf"


class IoShieldOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoShieldOutline"


class IoShieldSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoShieldSharp"


class IoShield(rx.Component):
    library = "react-icons/io5"
    tag = "IoShield"


class IoShirtOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoShirtOutline"


class IoShirtSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoShirtSharp"


class IoShirt(rx.Component):
    library = "react-icons/io5"
    tag = "IoShirt"


class IoShuffleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoShuffleOutline"


class IoShuffleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoShuffleSharp"


class IoShuffle(rx.Component):
    library = "react-icons/io5"
    tag = "IoShuffle"


class IoSkullOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSkullOutline"


class IoSkullSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSkullSharp"


class IoSkull(rx.Component):
    library = "react-icons/io5"
    tag = "IoSkull"


class IoSnowOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSnowOutline"


class IoSnowSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSnowSharp"


class IoSnow(rx.Component):
    library = "react-icons/io5"
    tag = "IoSnow"


class IoSparklesOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSparklesOutline"


class IoSparklesSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSparklesSharp"


class IoSparkles(rx.Component):
    library = "react-icons/io5"
    tag = "IoSparkles"


class IoSpeedometerOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSpeedometerOutline"


class IoSpeedometerSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSpeedometerSharp"


class IoSpeedometer(rx.Component):
    library = "react-icons/io5"
    tag = "IoSpeedometer"


class IoSquareOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSquareOutline"


class IoSquareSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSquareSharp"


class IoSquare(rx.Component):
    library = "react-icons/io5"
    tag = "IoSquare"


class IoStarHalfOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoStarHalfOutline"


class IoStarHalfSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoStarHalfSharp"


class IoStarHalf(rx.Component):
    library = "react-icons/io5"
    tag = "IoStarHalf"


class IoStarOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoStarOutline"


class IoStarSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoStarSharp"


class IoStar(rx.Component):
    library = "react-icons/io5"
    tag = "IoStar"


class IoStatsChartOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoStatsChartOutline"


class IoStatsChartSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoStatsChartSharp"


class IoStatsChart(rx.Component):
    library = "react-icons/io5"
    tag = "IoStatsChart"


class IoStopCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoStopCircleOutline"


class IoStopCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoStopCircleSharp"


class IoStopCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoStopCircle"


class IoStopOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoStopOutline"


class IoStopSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoStopSharp"


class IoStop(rx.Component):
    library = "react-icons/io5"
    tag = "IoStop"


class IoStopwatchOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoStopwatchOutline"


class IoStopwatchSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoStopwatchSharp"


class IoStopwatch(rx.Component):
    library = "react-icons/io5"
    tag = "IoStopwatch"


class IoStorefrontOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoStorefrontOutline"


class IoStorefrontSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoStorefrontSharp"


class IoStorefront(rx.Component):
    library = "react-icons/io5"
    tag = "IoStorefront"


class IoSubwayOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSubwayOutline"


class IoSubwaySharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSubwaySharp"


class IoSubway(rx.Component):
    library = "react-icons/io5"
    tag = "IoSubway"


class IoSunnyOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSunnyOutline"


class IoSunnySharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSunnySharp"


class IoSunny(rx.Component):
    library = "react-icons/io5"
    tag = "IoSunny"


class IoSwapHorizontalOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSwapHorizontalOutline"


class IoSwapHorizontalSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSwapHorizontalSharp"


class IoSwapHorizontal(rx.Component):
    library = "react-icons/io5"
    tag = "IoSwapHorizontal"


class IoSwapVerticalOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSwapVerticalOutline"


class IoSwapVerticalSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSwapVerticalSharp"


class IoSwapVertical(rx.Component):
    library = "react-icons/io5"
    tag = "IoSwapVertical"


class IoSyncCircleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSyncCircleOutline"


class IoSyncCircleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSyncCircleSharp"


class IoSyncCircle(rx.Component):
    library = "react-icons/io5"
    tag = "IoSyncCircle"


class IoSyncOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoSyncOutline"


class IoSyncSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoSyncSharp"


class IoSync(rx.Component):
    library = "react-icons/io5"
    tag = "IoSync"


class IoTabletLandscapeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTabletLandscapeOutline"


class IoTabletLandscapeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTabletLandscapeSharp"


class IoTabletLandscape(rx.Component):
    library = "react-icons/io5"
    tag = "IoTabletLandscape"


class IoTabletPortraitOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTabletPortraitOutline"


class IoTabletPortraitSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTabletPortraitSharp"


class IoTabletPortrait(rx.Component):
    library = "react-icons/io5"
    tag = "IoTabletPortrait"


class IoTelescopeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTelescopeOutline"


class IoTelescopeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTelescopeSharp"


class IoTelescope(rx.Component):
    library = "react-icons/io5"
    tag = "IoTelescope"


class IoTennisballOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTennisballOutline"


class IoTennisballSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTennisballSharp"


class IoTennisball(rx.Component):
    library = "react-icons/io5"
    tag = "IoTennisball"


class IoTerminalOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTerminalOutline"


class IoTerminalSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTerminalSharp"


class IoTerminal(rx.Component):
    library = "react-icons/io5"
    tag = "IoTerminal"


class IoTextOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTextOutline"


class IoTextSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTextSharp"


class IoText(rx.Component):
    library = "react-icons/io5"
    tag = "IoText"


class IoThermometerOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoThermometerOutline"


class IoThermometerSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoThermometerSharp"


class IoThermometer(rx.Component):
    library = "react-icons/io5"
    tag = "IoThermometer"


class IoThumbsDownOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoThumbsDownOutline"


class IoThumbsDownSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoThumbsDownSharp"


class IoThumbsDown(rx.Component):
    library = "react-icons/io5"
    tag = "IoThumbsDown"


class IoThumbsUpOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoThumbsUpOutline"


class IoThumbsUpSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoThumbsUpSharp"


class IoThumbsUp(rx.Component):
    library = "react-icons/io5"
    tag = "IoThumbsUp"


class IoThunderstormOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoThunderstormOutline"


class IoThunderstormSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoThunderstormSharp"


class IoThunderstorm(rx.Component):
    library = "react-icons/io5"
    tag = "IoThunderstorm"


class IoTicketOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTicketOutline"


class IoTicketSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTicketSharp"


class IoTicket(rx.Component):
    library = "react-icons/io5"
    tag = "IoTicket"


class IoTimeOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTimeOutline"


class IoTimeSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTimeSharp"


class IoTime(rx.Component):
    library = "react-icons/io5"
    tag = "IoTime"


class IoTimerOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTimerOutline"


class IoTimerSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTimerSharp"


class IoTimer(rx.Component):
    library = "react-icons/io5"
    tag = "IoTimer"


class IoTodayOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTodayOutline"


class IoTodaySharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTodaySharp"


class IoToday(rx.Component):
    library = "react-icons/io5"
    tag = "IoToday"


class IoToggleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoToggleOutline"


class IoToggleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoToggleSharp"


class IoToggle(rx.Component):
    library = "react-icons/io5"
    tag = "IoToggle"


class IoTrailSignOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrailSignOutline"


class IoTrailSignSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrailSignSharp"


class IoTrailSign(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrailSign"


class IoTrainOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrainOutline"


class IoTrainSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrainSharp"


class IoTrain(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrain"


class IoTransgenderOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTransgenderOutline"


class IoTransgenderSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTransgenderSharp"


class IoTransgender(rx.Component):
    library = "react-icons/io5"
    tag = "IoTransgender"


class IoTrashBinOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrashBinOutline"


class IoTrashBinSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrashBinSharp"


class IoTrashBin(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrashBin"


class IoTrashOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrashOutline"


class IoTrashSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrashSharp"


class IoTrash(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrash"


class IoTrendingDownOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrendingDownOutline"


class IoTrendingDownSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrendingDownSharp"


class IoTrendingDown(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrendingDown"


class IoTrendingUpOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrendingUpOutline"


class IoTrendingUpSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrendingUpSharp"


class IoTrendingUp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrendingUp"


class IoTriangleOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTriangleOutline"


class IoTriangleSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTriangleSharp"


class IoTriangle(rx.Component):
    library = "react-icons/io5"
    tag = "IoTriangle"


class IoTrophyOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrophyOutline"


class IoTrophySharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrophySharp"


class IoTrophy(rx.Component):
    library = "react-icons/io5"
    tag = "IoTrophy"


class IoTvOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoTvOutline"


class IoTvSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoTvSharp"


class IoTv(rx.Component):
    library = "react-icons/io5"
    tag = "IoTv"


class IoUmbrellaOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoUmbrellaOutline"


class IoUmbrellaSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoUmbrellaSharp"


class IoUmbrella(rx.Component):
    library = "react-icons/io5"
    tag = "IoUmbrella"


class IoUnlinkOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoUnlinkOutline"


class IoUnlinkSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoUnlinkSharp"


class IoUnlink(rx.Component):
    library = "react-icons/io5"
    tag = "IoUnlink"


class IoVideocamOffOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoVideocamOffOutline"


class IoVideocamOffSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoVideocamOffSharp"


class IoVideocamOff(rx.Component):
    library = "react-icons/io5"
    tag = "IoVideocamOff"


class IoVideocamOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoVideocamOutline"


class IoVideocamSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoVideocamSharp"


class IoVideocam(rx.Component):
    library = "react-icons/io5"
    tag = "IoVideocam"


class IoVolumeHighOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoVolumeHighOutline"


class IoVolumeHighSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoVolumeHighSharp"


class IoVolumeHigh(rx.Component):
    library = "react-icons/io5"
    tag = "IoVolumeHigh"


class IoVolumeLowOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoVolumeLowOutline"


class IoVolumeLowSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoVolumeLowSharp"


class IoVolumeLow(rx.Component):
    library = "react-icons/io5"
    tag = "IoVolumeLow"


class IoVolumeMediumOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoVolumeMediumOutline"


class IoVolumeMediumSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoVolumeMediumSharp"


class IoVolumeMedium(rx.Component):
    library = "react-icons/io5"
    tag = "IoVolumeMedium"


class IoVolumeMuteOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoVolumeMuteOutline"


class IoVolumeMuteSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoVolumeMuteSharp"


class IoVolumeMute(rx.Component):
    library = "react-icons/io5"
    tag = "IoVolumeMute"


class IoVolumeOffOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoVolumeOffOutline"


class IoVolumeOffSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoVolumeOffSharp"


class IoVolumeOff(rx.Component):
    library = "react-icons/io5"
    tag = "IoVolumeOff"


class IoWalkOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoWalkOutline"


class IoWalkSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoWalkSharp"


class IoWalk(rx.Component):
    library = "react-icons/io5"
    tag = "IoWalk"


class IoWalletOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoWalletOutline"


class IoWalletSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoWalletSharp"


class IoWallet(rx.Component):
    library = "react-icons/io5"
    tag = "IoWallet"


class IoWarningOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoWarningOutline"


class IoWarningSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoWarningSharp"


class IoWarning(rx.Component):
    library = "react-icons/io5"
    tag = "IoWarning"


class IoWatchOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoWatchOutline"


class IoWatchSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoWatchSharp"


class IoWatch(rx.Component):
    library = "react-icons/io5"
    tag = "IoWatch"


class IoWaterOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoWaterOutline"


class IoWaterSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoWaterSharp"


class IoWater(rx.Component):
    library = "react-icons/io5"
    tag = "IoWater"


class IoWifiOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoWifiOutline"


class IoWifiSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoWifiSharp"


class IoWifi(rx.Component):
    library = "react-icons/io5"
    tag = "IoWifi"


class IoWineOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoWineOutline"


class IoWineSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoWineSharp"


class IoWine(rx.Component):
    library = "react-icons/io5"
    tag = "IoWine"


class IoWomanOutline(rx.Component):
    library = "react-icons/io5"
    tag = "IoWomanOutline"


class IoWomanSharp(rx.Component):
    library = "react-icons/io5"
    tag = "IoWomanSharp"


class IoWoman(rx.Component):
    library = "react-icons/io5"
    tag = "IoWoman"


